import { EventEmitter, ComponentInterface } from "../../stencil-public-runtime";
import { Dayjs } from "dayjs";
import { CalendarSheet } from "./calendar-utils";
export declare class DatePicker implements ComponentInterface {
  /** The component DOM node */
  domNode: HTMLUxDatePickerElement;
  /** The currently active month (0-11) */
  activeMonth?: number;
  /** The currently active year (YYYY) */
  activeYear?: number;
  /** Format of the date value */
  dateFormat: string;
  /** Flag that controls if the field is disabled */
  disabled: boolean;
  /** Indicates if the field is mandatory */
  required: boolean;
  /** Indicates an invalid date */
  error: boolean;
  /** Error message that is rendered in invalid state */
  errorMsg: string | null;
  /** The weekday the calendar starts with (0=sunday, 1=monday, 6=saturday) */
  firstWeekday: number;
  /** Initial date, formatted according dateFormat pattern */
  initialValue: string;
  /** Input id attribute */
  inputId?: string;
  /** Controls the appearance of the control */
  kind: "default" | "form";
  /** Label text describing the input field */
  label?: string;
  /** The language in which texts are displayed */
  language?: string;
  /** Optionally, the date can be restricted to a maximum value (YYYY-MM-DD) */
  maxDate?: string;
  /** Optionally, the date can be restricted to a minimum value (YYYY-MM-DD) */
  minDate?: string;
  /** Input name attribute */
  name: string;
  /** Input placeholder text */
  placeholder?: string;
  /** Optional range start date (YYYY-MM-DD) */
  rangeStart: string;
  /** Optional range end date (YYYY-MM-DD) */
  rangeEnd: string;
  /** Label for the reset button */
  resetText?: string;
  /** Label for the today button */
  todayText?: string;
  /** Flag that indicates if the calendar is active */
  isActive: boolean;
  /** Storage for the currently visible calendar days */
  calendarSheet: CalendarSheet | null;
  /** Storage for the selected day */
  selectedDay: Dayjs | null;
  /** Storage for the ISO date of today */
  todayDateISO: string | null;
  /** Select a date */
  selectDate(value: string): Promise<void>;
  /** Emitted when a date is selected  */
  dateSelected: EventEmitter<{
    name: string;
    value: string;
  }>;
  /** Emitted when hovering a calendar day  */
  dateHover: EventEmitter<{
    name: string;
    value: string;
  }>;
  setInputId(): void;
  setLanguage(): void;
  setInitialValue(): void;
  setCalendarOptions(): void;
  setIsActive(): void;
  /** DOM node of the input element */
  private inputElement;
  private updateInputValue;
  private updateCalendar;
  private reset;
  private showToday;
  private getDayIsDisabled;
  private getIsInRange;
  private stepActiveMonth;
  private stepActiveYear;
  private handleClickField;
  private handleSelectDay;
  private handleHoverDay;
  private handleClickDoc;
  private handleInputChange;
  componentWillLoad(): void;
  disconnectedCallback(): void;
  render(): any;
}
