import { EventEmitter } from "../../stencil-public-runtime";
import { SwiperOptions } from "swiper";
/**
 * @slot (default) - your slides (must each be wrapped in <ux-slider-slide>)
 * @slot pagination - for the <ux-slider-pagination> element
 */
export declare class Slider {
  /** the instance of the swiper slider */
  private swiper;
  /** top offset of the arrow navigation, used if arrowsFollowImg prop is set */
  arrowsOffsetTop: number;
  /** watches for slides outside of the viewport, and if they are present, activates the slider anyway */
  hasOverflowingSlides: boolean;
  sliderElement: HTMLUxSliderElement;
  /** base class of the slider component */
  private baseClass;
  /** slider components references */
  private swiperContainer;
  /** the unique id of the slider, can only contain letters and numbers */
  private sliderId;
  /** if set, the slider has autoplay on */
  autoplay: boolean;
  /** if set, the slider has autoplay on */
  autoplayTime: number;
  /** the slider will pause when there the mouse hovers the slider */
  pauseOnHover: boolean | string;
  /** if set, set the sliding to be infinite. Note This can cause issues with certain web-components. If you encounter such problems, disable loop. */
  loop: boolean;
  /** if set, the slider will have no navigation arrows */
  noArrows: boolean;
  /** set the arrow navigation to be in the middle of the image, instead of the whole slider */
  arrowsFollowImg: boolean | string;
  /** if set, the swiping will be disabled for mouse drags */
  noDrag: boolean;
  /** slide transition effect: one of: "slide", "fade", "cube", "coverflow", "flip" */
  effect: string;
  /** the speed of the slide stransitions */
  speed: number;
  /** sets the number of visible slides on XL viewports */
  visibleSlidesXl: number | "auto";
  /** sets the number of visible slides on large viewports */
  visibleSlidesL: number | "auto";
  /** sets the number of visible slides on medium viewports */
  visibleSlidesM: number | "auto";
  /** sets the number of visible slides on small viewports */
  visibleSlidesS: number | "auto";
  /** sets the custom breakpoint for large viewports */
  breakpointL: number;
  /** sets the custom breakpoint for medium viewports */
  breakpointM: number;
  /** sets the custom breakpoint for small viewports */
  breakpointS: number;
  /** sets the space between slides for XL viewports */
  spaceBetweenXl: number;
  /** sets the space between slides for large viewports */
  spaceBetweenL: number;
  /** sets the space between slides for medium viewports */
  spaceBetweenM: number;
  /** sets the space between slides for small viewports */
  spaceBetweenS: number;
  /** sets the inner container width for XL viewports */
  containerWidthXl: string;
  /** sets the inner container width for large viewports */
  containerWidthL: string;
  /** sets the inner container width for medium viewports */
  containerWidthM: string;
  /** sets the inner container width for small viewports */
  containerWidthS: string;
  /** sets the slides per columns for XL viewports */
  slidesPerColumnXl: number;
  /** sets the slides per columns for large viewports */
  slidesPerColumnL: number;
  /** sets the slides per columns for medium viewports */
  slidesPerColumnM: number;
  /** sets the slides per columns for small viewports */
  slidesPerColumnS: number;
  /** sets the slides per group of for xl viewports */
  slidesPerGroupXl: number;
  /** sets the slides per group of for large viewports */
  slidesPerGroupL: number;
  /** sets the slides per group for medium viewports */
  slidesPerGroupM: number;
  /** sets the slides per group for small viewports */
  slidesPerGroupS: number;
  /** additional classes that will be added to an inner div,
   * used to set utility classes that will control the internal width of the slides
   */
  containerClasses: string;
  /** if set, slider will be centered, with the addions of shadows
   * on the sides to cut off excess slides on tablet viewports
   **/
  fadedSides: boolean;
  /** if set, the slides will have overflow visible, useful when the slides have outer shadow */
  slidesOverflowVisible: boolean;
  /** if set, height of the slides will be alligned with the max height of the container */
  slidesAutoHeight: boolean;
  /** if set, the height of the slider will be equal to the current visible slide */
  autoHeight: boolean;
  /** if set,slider will reinitialise itself on resize */
  reinitOnResize: boolean;
  private pauseOnHoverInitialized;
  /** if lazy loading is active, the slider will emit events accordingly */
  private hasLazyLoad;
  /** Known bug on safari: the sidebar is not taken into consideration by swiper
   * in the calculation of breakpoints, therefore we need to "help" it wiith a manual
   * adjustment. The value holds the width of a possible sidebar in Safari.
   */
  private safariSidebarAdjustment;
  /** event to go to previous slide */
  updatePagination: EventEmitter;
  /** event emitted when the slider is initialised */
  sliderInitialised: EventEmitter;
  options: SwiperOptions;
  /** Updates the number of slides per view of the slider
   * it expects a number as argument
   */
  updateSlidesPerView(slidesPerView: number): Promise<void>;
  /** Updates the slider with the native update() method from swiper
   * It works effectively only for minor updates (size, spacing etc.)
   */
  updateSoft(): Promise<void>;
  /** Update method to be used to reser and update the slider completely.
   * It can receive an optional argument with valid swiper options.
   * See Swiper API for more information of valid options.
   */
  update(additionalOptions?: {}): Promise<void>;
  /** Adds the slide passed as an argument to the slider. */
  addSlide(slide: Node | string, before?: boolean): Promise<void>;
  /** Removes the slide that has the index specified as the argument from the slider */
  removeSlide(index: number): Promise<void>;
  /** go to next slide */
  slideNext(): Promise<void>;
  /** go to previous slide */
  slidePrev(): Promise<void>;
  sliderStopAutoplay(event: CustomEvent): void;
  sliderResumeAutoplay(event: CustomEvent): void;
  nextSlideHandler(event: CustomEvent): void;
  previousSlideHandler(event: CustomEvent): void;
  componentWillLoad(): void;
  componentDidLoad(): void;
  private handleArrowsPosition;
  private onResize;
  private handleMouseActions;
  private handleMouseOver;
  private handleMouseLeave;
  private initPauseOnHover;
  connectedCallback(): void;
  disconnectedCallback(): void;
  private calculateSlidesOverflow;
  /** manages the visible state of duplicates slider when there is no overflow */
  handleDuplicatesFlag: any;
  render(): any;
}
