import { EventEmitter } from "../../stencil-public-runtime";
export declare class Tooltip {
  private baseClass;
  /** the target of the tooltip, hover (or click) on the element activates the tooltip */
  private tooltipTargetElement;
  /** indicates when the tooltip was last activated, used to provide a more accurate
   * timeout for deactivation.
   */
  private lastActivated;
  /** the tooltip message itself */
  private tooltipElement;
  /** used to calculate whether the tooltip can be placed in a certain alignment or not,
   * added to the dimensions of the tooltip message to give some extra space around it
   */
  private safeMargin;
  private tooltipDimensions;
  /** ux-tooltip element */
  element: HTMLUxTooltipElement;
  /** the css selector of the tooltip target, tooltip and target
   * have to have the same parent element
   */
  tooltipTarget: string;
  /** the desired alignment of the tooltip message */
  align: "right" | "bottom" | "left" | "top";
  /** set to true if the tooltip should be controlled from outside instead of handling UI events itself */
  controlled: boolean;
  /** the actual alignment of the tooltip message */
  tooltipAlignment: any;
  /** DOMRects of the tooltip message */
  tooltipPosition: {
    top: number;
    left: number;
  };
  /** activated if there is only text as content of the tooltip */
  textOnlyMode: boolean;
  /** unique ID used to keep track of what tooltip is active */
  uniqueId: string;
  /** flag that indicates if the tooltip is currently active or not */
  isTooltipActive: boolean;
  /** DOMRects of the tooltip target */
  tooltipTargetRects: DOMRect;
  /** used when the tooltip is aligned to the bottom but the tooltip target is so on the
   * sides that the arrow can not hold its natural center position but have to be moved
   * to the sides in order to be directly under the target
   */
  customArrowPosition: false | number;
  setControlled(): void;
  calculatePosition(): void;
  /** show/activate the tooltip */
  showTooltip(): Promise<void>;
  /** hide/deactivate the tooltip */
  hideTooltip(): Promise<void>;
  connectedCallback(): void;
  componentWillLoad(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  private addEventListeners;
  private removeEventListeners;
  private scrollHandler;
  private handleTooltipClick;
  private activateTooltip;
  private deactivateTooltip;
  /** mainly for mobile: click on the target will open the tooltip,
   * click outside of tooltip self will close it
   */
  handleClicks(e: Event): void;
  private calculateTooltipPosition;
  /** setting the tooltip in different positions */
  private setTooltipToRight;
  private setTooltipToLeft;
  private setTooltipToTop;
  /** bottom alignment will also cause an adjustment to the tooltip
   * pointer arrow position if necessary.
   */
  private setTooltipToBottom;
  calculateArrowPosition: boolean;
  componentDidRender(): void;
  /** Preventing multiple Tooltip avtive at the same time */
  activatedTooltipEvent: EventEmitter<string>;
  preventMultipleTooltipsActive(event: CustomEvent): void;
  render(): any;
}
